summaryrefslogtreecommitdiffstats
path: root/test/links_env.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/links_env.c')
-rw-r--r--test/links_env.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/links_env.c b/test/links_env.c
index b9ecafa..efc7c1e 100644
--- a/test/links_env.c
+++ b/test/links_env.c
@@ -138,8 +138,8 @@ external_link_env(hid_t fapl, hbool_t new_format)
*
* Purpose: Test external link with environment variable HDF5_EXT_PREFIX
*
* Return: Success: exit(0)
* Failure: exit(non-zero)
*
* Programmer: Vailin Choi; Nov 2010
*
@@ -175,7 +175,7 @@ main(void)
if(nerrors) {
HDprintf("***** %d External Link (HDF5_EXT_PREFIX) test%s FAILED! *****\n",
nerrors, 1 == nerrors ? "" : "s");
- HDexit(1);
+ HDexit(EXIT_FAILURE);
}
HDprintf("All external Link (HDF5_EXT_PREFIX) tests passed.\n");
@@ -138,8 +138,8 @@ external_link_env(hid_t fapl, hbool_t new_format)
* Purpose: Test external link with environment variable HDF5_EXT_PREFIX
*
- * Return: Success: exit(0)
- * Failure: exit(non-zero)
+ * Return: Success: exit(EXIT_SUCCESS)
+ * Failure: exit(EXIT_FAILURE)
*
* Programmer: Vailin Choi; Nov 2010